summaryrefslogtreecommitdiff
path: root/include/test_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/test_util.h')
-rw-r--r--include/test_util.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/test_util.h b/include/test_util.h
index bfcd940cea..21ea21595b 100644
--- a/include/test_util.h
+++ b/include/test_util.h
@@ -283,20 +283,20 @@ struct test_i2c_write_dev {
* specified port and slave address returns error.
*
* @param port The port that the detached device is connected to
* @param slave_addr The address of the detached device
* @return EC_SUCCESS if detached; EC_ERROR_OVERFLOW if too many devices are
* detached.
*/
-int test_detach_i2c(const int port, const uint16_t slave_addr_flags);
+int test_detach_i2c(const int port, const uint16_t periph_addr_flags);
/*
* Re-attach an I2C device.
*
* @param port The port that the detached device is connected to
* @param slave_addr The address of the detached device
* @return EC_SUCCESS if re-attached; EC_ERROR_INVAL if the specified device
* is not a detached device.
*/
-int test_attach_i2c(const int port, const uint16_t slave_addr_flags);
+int test_attach_i2c(const int port, const uint16_t periph_addr_flags);
#endif /* __CROS_EC_TEST_UTIL_H */
@@ -283,20 +283,20 @@ struct test_i2c_write_dev {
*
* @param port The port that the detached device is connected to
- * @param slave_addr The address of the detached device
+ * @param periph_addr The address of the detached device
* @return EC_SUCCESS if detached; EC_ERROR_OVERFLOW if too many devices are
* detached.
@@ -283,20 +283,20 @@ struct test_i2c_write_dev {
*
* @param port The port that the detached device is connected to
- * @param slave_addr The address of the detached device
+ * @param periph_addr The address of the detached device
* @return EC_SUCCESS if re-attached; EC_ERROR_INVAL if the specified device
* is not a detached device.